# redata-commons

[![GitHub Actions Sphinx build status](https://img.shields.io/github/workflow/status/UAL-RE/redata-commons/Sphinx%20Docs%20Check?label=sphinx&color=blue)](https://github.com/UAL-RE/redata-commons/actions?query=workflow%3A%22Sphinx+Docs+Check%22)
[![RTDs build status](https://readthedocs.org/projects/redata-commons/badge/?version=latest&style=flat)](https://redata-commons.readthedocs.io/en/latest/)

This repository contains commonly used codes by ReDATA software. For our documentation, please click on the links below or visit [Read the Docs](https://redata-commons.readthedocs.io/en/latest/) directly.

- [Overview](https://redata-commons.readthedocs.io/en/latest/#overview)
- [Installation](https://redata-commons.readthedocs.io/en/latest/installation.html)
- [Execution](https://redata-commons.readthedocs.io/en/latest/execution.html)
    - [Using `git_info`](https://redata-commons.readthedocs.io/en/latest/execution.html#using-git-info)
    - [Using `logger`](https://redata-commons.readthedocs.io/en/latest/execution.html#using-logger)
- [Authors](https://redata-commons.readthedocs.io/en/latest/authors.html)
- [License](#license)
- [API Documentation](https://redata-commons.readthedocs.io/en/latest/modules.html)


## License

This project is licensed under the [MIT License](https://opensource.org/licenses/MIT) - see the [LICENSE](LICENSE) file for details.
